@@ -47,6 +47,7 @@ COMMON_ERRRORS: List[Dict[str, Any]] = [
 
 VEHICLE_SPECIFICATIONS: Dict[str, Dict[str, Any]] = {
     "X101VE": {  # ZOE phase 1
+        "reports-charge-session-durations-in-minutes": True,
         "reports-in-watts": True,
         "support-endpoint-location": False,
         "support-endpoint-lock-status": False,
@@ -54,6 +55,9 @@ VEHICLE_SPECIFICATIONS: Dict[str, Dict[str, Any]] = {
     "X102VE": {  # ZOE phase 2
         "warns-on-method-set_ac_stop": "Action `cancel` on endpoint `hvac-start` may not be supported on this model.",  # noqa
     },
+    "XJA1VP": {  # CLIO V
+        "support-endpoint-hvac-status": False,
+    },
     "XJB1SU": {  # CAPTUR II
         "support-endpoint-hvac-status": False,
     },
@@ -64,6 +68,7 @@ VEHICLE_SPECIFICATIONS: Dict[str, Dict[str, Any]] = {
 
 GATEWAY_SPECIFICATIONS: Dict[str, Dict[str, Any]] = {
     "GDC": {  # ZOE phase 1
+        "reports-charge-session-durations-in-minutes": True,
         "reports-in-watts": True,
         "support-endpoint-location": False,
         "support-endpoint-lock-status": False,
@@ -195,10 +200,20 @@ class KamereonVehicleDetails(BaseModel):
         if energy_type in [
             "OTHER",
             "PHEV",
+            "HEV",
         ]:
             return True
         return False
 
+    def reports_charge_session_durations_in_minutes(self) -> bool:
+        """Return True if model reports history durations in minutes."""
+        # Default to False (=seconds) for unknown vehicles
+        if self.model and self.model.code:
+            return VEHICLE_SPECIFICATIONS.get(self.model.code, {}).get(
+                "reports-charge-session-durations-in-minutes", False
+            )
+        return False  # pragma: no cover
+
     def reports_charging_power_in_watts(self) -> bool:
         """Return True if model reports chargingInstantaneousPower in watts."""
         # Default to False for unknown vehicles
